"""manipy: Latent-space manipulation utilities and models.

This package provides utilities, models, and scripts for working with
StyleGAN latent spaces and training flow/rating models.
"""

__all__ = [
    "config",
    "core",
]

# Keep version in one obvious place for packaging
__version__ = "0.1.0"

